clear
clc

%% set stream-set to be used

t1={[26;1], [125;1], 1, 1}; %a1
t2={[26;1], [125;1], 1, 2}; %a2
t3={[26;1], [250;1], 2, 3}; %b1
t4={[26;1], [125;1], 3, 4}; %best effor
t5={[26;1], [125;1], 3, 5}; %best effort

ts={t1 t2 t3 t4 t5};

%% set the time for the sumilation to run
timeToSimulate=10000;


%define TAS as one or more vectors of 4 values: first value is the period
%of the tas (these should be equal among all vectors); second value is the
%size of the guard band (these should be equal among all vectors); third is
%the size of the CDT slot and forth is the offset with respect to the start
%of the TAS schedule (these values should be different from one another)

%% AVB scenario (no TAS)
tas_AVB = [500, 0, 0, 0];

%% single Protected Window
tas1PW=[500, 26, 150, 0];

%% two Protected Windows
tas1=[500, 26, 14, 0];
tas2=[500, 26, 14, 100];
tas2PW=[tas1; tas2];

%% Choose which TAS configuration to choose.
% If tas_AVB is choosen, then there is no bandwidth reserverd for CDT streams (nor for the guard-band), hence only AVB and BE streams are present in the switch, making it an AVB switch.
% To make it easier for the artifact evaluation, all three settings are ran
% in a for loop below

%tas = tas_AVB;
%tas = tas1PW;
%tas = tas2PW;

%% define slopes

slopeA=[80;20];
slopeB=[20;80];
slopeC=[0;0];
slopes=[slopeA slopeB slopeC];

%% start simulation
for i=1:3
    
    if i==1
        tas = tas_AVB;
    end
    
    if i==2
        tas = tas1PW;
    end
    
    if i==3
        tas = tas2PW;
    end
    
    ResponseTimes={};
    
    for offsetTASinput = 1:500
        
        offsetTAS=offsetTASinput-0.0000001;
        
        %do the simulaton
        [RTS1, finishTimesS1, graficS1, creditShapeS1, runableTaskSetS1] = TSN_simulateExecutionOfPRTSMultipleJobsStopAtDeadline(ts, ceil(timeToSimulate/max(ts{end}{2}(1,:))), slopes, tas, offsetTAS, []);
        
        ResponseTimes{end+1,1} = {RTS1};
        
    end
    
    if i==1
        display('The results for the AVB simulation are as follows')
    end
    
    if i==2
        display('The results for the TSN simulation with a single Protected Window are as follows')
    end
    
    if i==3
        display('The results for the TSN simulation with two Protected Windows are as follows')
    end
    
    %display results
    display('The worst case transmission delays observed on Switch S1 for streams A1, A2 and B1 are as follows:')
    DelaysObservedDuringSimulation = ProcessSimulationResults (ResponseTimes, 3) % the second parameter needs to be 3, as there are 3 AVB streams in the switch
    
    display('The theoretical worst case transmission delays computed on Switch S1 for streams A1, A2 and B1 in the TSN case are as follows:')
    TSN_TheoreticalDelays = TSN_streamSet_analysis (3, ts, slopes, tas)
    
    display('The theoretical worst case transmission delays computed on Switch S1 for streams A1, A2 and B1 in the AVB case (no TAS) would be as follows:')
    AVB_TheoreticalDelays = AVB_streamSet_analysis (3, ts, slopes)
    
end

display('finished')

